<html>
<head>
<link rel="stylesheet" type="text/css" href="../styles/Style.css">
<script language="JavaScript" type="text/javascript" src="ajax.js"></script>
</head>
<body>
<?php
require_once("../class/class.conectar.php");
require_once("../class/class.jefaturas.php");
require_once("../class/class.vacaciones.php");
require_once("../class/class.usuaprueba.php");
require_once("../class/class.usutrab.php");

$Objcon = new Conectar();
$conex = $Objcon->con();

if(isset($_GET['idj']) && isset($_GET['ids']) && isset($_GET['idtp']) && isset($_GET['anno'])  && isset($_GET['mes'])){
$idj = $_GET['idj'];
$ids = $_GET['ids'];
$idtp = $_GET['idtp'];
$anno = $_GET['anno'];
$mm = $_GET['mes'];
}

//listar servicios del departamento

//armando grupo de servicios y sus dependencias
$cad="";
$Objj = new Jefaturas();
$datosj[] = array();
$datosj1=$Objj->buscar_jefatura($conex,$idj);
$datosj2=$Objj->listar_jefatura_servicio($conex,$idj);
$datosj=array_merge($datosj1, $datosj2);
for($i=0;$i<count($datosj);$i++){
$cad = $cad."<td width='10' class='facetfilaTD' align='center' >".$datosj[$i]['abrev']."</td>";
}

$a=count($datosj);
$Objua = new UsuarioAprueba();
$res_pval=array();$res_eval=array();
$res_pval=$Objua->ask_prog_validado($conex,$anno,$mm,$ids,$idj,$idtp);
$res_eval=$Objua->ask_eje_validado($conex,$anno,$mm,$ids,$idj);

//si no esta validado
if(count($res_pval)==0){
$save=0;
}else{
//si esta validado
$save=1;
}
//si esta validado la ejecucion
if(count($res_eval)!=0){
$save2=1;
}else{
$save2=0;
}

//validar el boton de grabar
$Objut = new UsuarioTrabaja();
$res_ut = array();
$res_ut = $Objut->ask_usu_prog($conex,$idj,$ids,$anno,$mm,$idtp);

$validarboton ="<table align='center'><tr><td colspan='2' align='center'><input type='button'  value='Programar'  id='programar' name='programar' onClick='programarpersonal()' ";
if(count($res_ut)==0 ){
$validarboton =$validarboton." class='llenarnoboton' disabled ";
}else{
$validarboton =$validarboton." class='llenarboton' ";
}
$validarboton =$validarboton."/></td></tr><tr><td align='center'><img src='../img/home.png' width='70' height='60' onClick='regresarMP()'></td></tr></table><br>";
///////////////////////

echo "<input type='hidden' id='idj' name='idj' value='".$idj."'>";
echo "<input type='hidden' id='ids' name='ids' value='".$ids."'>";
echo "<input type='hidden' id='anno' name='anno' value='".$anno."'>";
echo "<input type='hidden' id='mes' name='mes' value='".$mm."'>";
echo "<input type='hidden' id='idtp' name='idtp' value='".$idtp."'>";
echo "<input type='hidden' id='nserv' name='nserv' value='".$a."'>";


$cadena1 = "<table><tr><td colspan='10' align='center' height='25' class='LlenarTablaGarea'>LISTADO DEL PERSONAL PROGRAMADO</td></tr>";
$cadena1 = $cadena1."<tr><td width='50' class='facetfilaTD' rowspan='2'>CODIGO</td><td width='300' class='facetfilaTD' rowspan='2' align='center'>NOMBRE DEL PERSONAL</td><td width='300' class='facetfilaTD' colspan='$a' align='center'>SERVICIO A PROGRAMAR</td><td width='200' class='facetfilaTD' align='center' rowspan='2'>VACACIONES</td></tr>";
$cadena1 = $cadena1.$cad;

//cabecera para el personal no programado
$cadena2 = "<table><tr><td colspan='10' align='center'  height='25' class='LlenarTablaGarea'>LISTADO DEL PERSONAL NO PROGRAMADO</td></tr>";
$cadena2 = $cadena2."<tr><td width='50' class='facetfilaTD' rowspan='2'>CODIGO</td><td width='300' class='facetfilaTD' rowspan='2' align='center'>NOMBRE DEL PERSONAL</td><td width='300' class='facetfilaTD' colspan='$a' align='center'>SERVICIO A PROGRAMAR</td><td width='200' class='facetfilaTD' align='center' rowspan='2'>VACACIONES</td></tr>";
$cadena2 = $cadena2.$cad;

//cabecera para el personal de apoyo
$cadena3 = "<table><tr><td colspan='10' align='center' height='25' class='LlenarTablaGarea'>LISTADO DEL PERSONAL DE APOYO</td></tr>";
$cadena3 = $cadena3."<tr><td width='50' class='facetfilaTD' rowspan='2'>CODIGO</td><td width='300' class='facetfilaTD' rowspan='2' align='center'>NOMBRE DEL PERSONAL</td><td width='300' class='facetfilaTD' colspan='$a' align='center'>SERVICIO QUE PERTENECE</td><td width='200' class='facetfilaTD' align='center' rowspan='2'>VACACIONES</td></tr>";
$cadena3 = $cadena3.$cad;

//si es que ho hay nada resgitrado del mes
$pp=0;
$pa=0;
$pnp=0;
$nnpp=-1;
$ja=-1;
//$nnpp=1;

////////////////
if($pp==0){
		$Objut = new UsuarioTrabaja();
		$res_lis=array();
		$res_lis = $Objut->listar_per_trab_per($conex,$anno,$mm,$idj,$ids,$ids,$idtp);
		$w=0;
		if(count($res_lis)>0){
		//echo "entro por aqui";
		for($i=0;$i<sizeof($res_lis);$i++){
		$pp= 1;
		$codigo1 = $res_lis[$i]['cod'];
		$ja = $ja + 1;
		//$ja
		$nnpp = $nnpp +1;
		$cadena1 = $cadena1."<tr><td align='center' class ='FacetDataTextC'><input type='text' size='3' id='cod[".$nnpp."]' name='cod[".$nnpp."]' value='".utf8_encode($res_lis[$i]['codigo'])."'></td><td class ='FacetDataTextC'>".utf8_encode($res_lis[$i]['nombre'])."</td>";
		$cadena1 = $cadena1."<input type='hidden' id='idcod[".$nnpp."]' name='idcod[".$nnpp."]' value='".$codigo1."'>";
		for($s=0;$s<sizeof($datosj);$s++){
		//for($i=1;$i<=$a;$i++){
			$idsa = $datosj[$s]['ids'];
			//$sal = 0;
			$Objut = new UsuarioTrabaja();
			$res_lis2 = array();
			$res_lis2 = $Objut->buscar_per_trab($conex,$codigo1,$anno,$mm,$idj,$idsa,$idtp);
				//consultar
				if(count($res_lis2)>0){
				if($idsa==$res_lis2[0]['idsa']){
				$sal = 1;
				}else{$sal = 0; }
				}else{$sal = 0; }
			$cadena1 = $cadena1."<td align='center' class ='FacetDataTextC'><input type='checkbox' name='serv1[".$ja."]' id='serv1[".$ja."]' ";
			if ($sal==1){
				$cadena1 =$cadena1."CHECKED ></td>";
			}else{
				$cadena1=$cadena1."></td>";
			}
			}
			//pregunta por descanso medico
			/*
			$Objdm = new DescansoMedico();
			$Objdm->consultar_descmed_fecha($codper,$fecha);
			$sqlaskdmi="select * from tb_descmed where year(dm_fechaini)='$anno' and month(dm_fechaini)='$mm' and ug_id='$codigo1'";
			$sqlaskdmf="select * from tb_descmed where year(dm_fechafin)='$anno' and month(dm_fechafin)='$mm' and ug_id='$codigo1'";
			//echo $sqlaskdmi;
			$resultsql1 = mysql_query($sqlaskdmi);
			$resultsql2 = mysql_query($sqlaskdmf);
			if((mysql_num_rows($resultsql1)!=0) || (mysql_num_rows($resultsql2)!=0)){
			$cadena1=$cadena1."<td align='center' class ='FacetDataTextC'><img src='../personal/img/ver.jpg' width='17' height='17' value='$codigo1' onClick=verdescandomedico(this.value);></td>";
			}else{
			$cadena1=$cadena1."<td class ='FacetDataTextC'></td>";
			}
			*/
			//pregunta por vacaciones 
			$Objvi = new Vacaciones();
			$Objvf = new Vacaciones();
			$res_vi = array();
			$res_vf = array();
			$res_vi=$Objvi->consultar_vacaciones_anno_mes_ini($conex,$codigo1, $anno, $mm);
			$res_vf=$Objvf->consultar_vacaciones_anno_mes_fin($conex,$codigo1, $anno, $mm);
			
			if((count($res_vi)>0) || (count($res_vf)>0)){
				$w=$w+1;
			$cadena1=$cadena1."<td align='center' class ='FacetDataTextC'><img src='../personal/img/ver.jpg' width='17' height='17' value='$codigo1' onClick=vervacaciones($w);></td>";
			$cadena1 = $cadena1."<input type='hidden' id='codp".$w."' name='codp".$w."' value='".$codigo1."'>";
			}else{
			$cadena1=$cadena1."<td class ='FacetDataTextC'></td>";
			}
			$cadena1 = $cadena1."</tr>";
			}
		 }//end if
}

if($pnp==0){
		//listar personal
		$Objut = new UsuarioTrabaja();
		$res_np=array();
		$res_np = $Objut->listar_per_trab_per_np($conex,$anno,$mm,$idj,$ids,$ids,$idtp);
		$jc=0;
		
		for($np=0;$np<sizeof($res_np);$np++){
		$pnp= 1;
		$ja = $ja +1;
		$codigo2 = $res_np[$np]['cod'];
		$nnpp = $nnpp +1;
		$cadena2 = $cadena2."<tr><td align='center' class ='FacetDataTextC'><input type='text' size='3' id='cod[".$nnpp."]' name='cod[".$nnpp."]' value='".utf8_encode($res_np[$np]['codigo'])."'></td><td class ='FacetDataTextC'>".utf8_encode($res_np[$np]['nombre'])."</td>";
		$cadena2 = $cadena2."<input type='hidden' id='idcod[".$nnpp."]' name='idcod[".$nnpp."]' value='".$codigo2."'>";
		
		for($i=0;$i<sizeof($datosj);$i++){
		$cadena2 = $cadena2."<td align='center' class ='FacetDataTextC'><input type='checkbox' name='serv1[".$ja."]' id='serv1[".$ja."]' ";
		$idsp = $datosj[$i]['ids'];
		if($idsp==$res_np[$np]['ids']){
		$cadena2 =$cadena2."CHECKED ></td>";
		}else{
		$cadena2=$cadena2."></td>";
		}
		}
	//pregunta por descanso medico
	/*
			$sqlaskdmi="select * from tb_descmed where year(dm_fechaini)='$anno' and month(dm_fechaini)='$mm' and ug_id='$codigo2'";
			$sqlaskdmf="select * from tb_descmed where year(dm_fechafin)='$anno' and month(dm_fechafin)='$mm' and ug_id='$codigo2'";
			//echo $sqlaskdmi;
			$resultsql1 = mysql_query($sqlaskdmi);
			$resultsql2 = mysql_query($sqlaskdmf);
			if((mysql_num_rows($resultsql1)!=0) || (mysql_num_rows($resultsql2)!=0)){
			$cadena2=$cadena2."<td align='center' class ='FacetDataTextC'><img src='../personal/img/ver.jpg' width='17' height='17' value='$codigo2' onClick=verdescandomedico(this.value);></td>";
			}else{
			$cadena2=$cadena2."<td class ='FacetDataTextC'></td>";
			}
		*/	
	
	//pregunta por vacaciones 
			//pregunta por vacaciones 
			$Objvi = new Vacaciones();
			$Objvf = new Vacaciones();
			$res_vi = array();
			$res_vf = array();
			$res_vi=$Objvi->consultar_vacaciones_anno_mes_ini($conex,$codigo2, $anno, $mm);
			$res_vf=$Objvf->consultar_vacaciones_anno_mes_fin($conex,$codigo2, $anno, $mm);
			
			if((count($res_vi)>0) || (count($res_vf)>0)){
				$w=$w+1;
			$cadena2=$cadena2."<td align='center' class ='FacetDataTextC'><img src='../personal/img/ver.jpg' width='17' height='17' value='$codigo2' onClick=vervacaciones($w);></td>";
			$cadena2 = $cadena2."<input type='hidden' id='codp".$w."' name='codp".$w."' value='".$codigo2."'>";
			}else{
			$cadena2=$cadena2."<td class ='FacetDataTextC'></td>";
			}
			$cadena2 = $cadena2."</tr><input type='hidden' id='npp' name='npp' value='".$jc."'>";
		}
}


////
//listado del personal de apoyo	
$npa=-1;	
if($pa==0){
		$Objut = new UsuarioTrabaja();
		$res_npa = array();
		$res_npa = $Objut->listar_per_trab_per_pa_np($conex,$anno,$mm,$idj,$ids,$ids,$idtp);
		$ja=0;
		
		for($paa=0;$paa<sizeof($res_npa);$paa++){
		$pa=1;
		$codigo = $res_npa[$paa]['cod'];
		$ja = $ja + 1;
		$npa = $npa +1;
		$cadena3 = $cadena3."<tr><td align='center' class ='FacetDataTextC'><input type='text' size='3'  id='codapoyo[".$npa."]' name='codapoyo[".$npa."]' value='".utf8_encode($res_npa[$paa]['codigo'])."'></td><td class ='FacetDataTextC'>".utf8_encode($res_npa[$paa]['nombre'])."</td>";
		$cadena3 = $cadena3."<input type='hidden' id='idcodapoyo[".$npa."]' name='idcodapoyo[".$npa."]' value='".$codigo."'>";
		
		for($s=0;$s<sizeof($datosj);$s++){
		//for($i=1;$i<=$a;$i++){
			$idsa = $datosj[$s]['ids'];
			$sal = 0;
			$res_so = array();
			$res_so = $Objut->buscar_per_trab_serv($conex,$anno,$mm,$idj,$ids,$idtp,$codigo);
				for($so=0;$so<sizeof($res_so);$so++){
				if($idsa==$res_so[$so]['idsa']){
				$sal = 1;
				break;
				}else{$sal = 0; }}
			$cadena3 = $cadena3."<td align='center' class ='FacetDataTextC'>";
			if ($sal==1){
				$cadena3 =$cadena3."X</td>";
				$cadena3 =$cadena3."<input type='hidden' id='idsa[".$npa."]' name='idsa[".$npa."]' value='".$idsa."'>";
			}else{
				$cadena3=$cadena3."</td>";
				}}
			/*	
			//pregunta por descanso medico
			$sqlaskdmi="select * from tb_descmed where year(dm_fechaini)='$anno' and month(dm_fechaini)='$mm' and ug_id='$codigo'";
			$sqlaskdmf="select * from tb_descmed where year(dm_fechafin)='$anno' and month(dm_fechafin)='$mm' and ug_id='$codigo'";
			//echo $sqlaskdmi;
			$resultsql1 = mysql_query($sqlaskdmi);
			$resultsql2 = mysql_query($sqlaskdmf);
			if((mysql_num_rows($resultsql1)!=0) || (mysql_num_rows($resultsql2)!=0)){
			$cadena3=$cadena3."<td align='center' class='FacetDataTextC'><img src='../personal/img/ver.jpg' width='17' height='17' value='$codigo' onClick=verdescandomedico(this.value);></td>";
			}else{
			$cadena3=$cadena3."<td class ='FacetDataTextC'></td>";
			}
			*/
			
			//pregunta por vacaciones 
			$Objvi = new Vacaciones();
			$Objvf = new Vacaciones();
			$res_vi = array();
			$res_vf = array();
			$res_vi=$Objvi->consultar_vacaciones_anno_mes_ini($conex,$codigo, $anno, $mm);
			$res_vf=$Objvf->consultar_vacaciones_anno_mes_fin($conex,$codigo
, $anno, $mm);

			if((count($res_vi)>0) || (count($res_vf)>0)){
			$cadena3=$cadena3."<td align='center' class='FacetDataTextC'><img src='../personal/img/ver.jpg' width='17' height='17' value='$codigo' onClick=vervacaciones(this.value);></td>";
			}else{
			$cadena3=$cadena3."<td class ='FacetDataTextC'></td>";
			}
			$cadena3 = $cadena3."</tr>";
			}

}

//$nnpp = $pp + $pa + $pnp;
echo "<input type='hidden' id='nnpp' name='nnpp' value='".$nnpp."'>";
echo "<input type='hidden' id='npa' name='npa' value='".$npa."'>";

		
		
		
//$cadena1 = $cadena1."<tr><td colspan='9' align='center'><input type='button' value='Grabar'></td></tr></table><br><br>";
$cadena1 = $cadena1."</table><br><br>";
//$cadena2 = $cadena2."<tr><td colspan='9' align='center'><input type='button' value='Grabar'></td></tr></table><br><br>";
$cadena2 = $cadena2."</table><br><br>";
//$cadena3 = $cadena3."<tr><td colspan='9' align='center'><input type='button' value='Grabar'></td></tr></table><br><br>";
$cadena3 = $cadena3."</table><br><br>";
//$cadena3 = $cadena3."<tr><td colspan='9' align='center'><input type='button' value='Grabar'></td></tr>";

////////////////////////
echo $validarboton;
if($pp==1){

echo "<div id='divperprog'>".$cadena1."</div>";
}
if($pnp==1){
echo "<div id='divpernoprog'>".$cadena2."</div>";
}
if($pa==1){
echo "<div id='divperapoy'>".$cadena3."</div>";
}
echo "<center><input type='button' value='Grabar'  onClick='grabarPersonalProg()'"; if(($save2==1)|| ($save==1)){ echo " class='llenarnoboton' disabled";}else{ echo " class='llenarboton'";} echo "></center>";
?>
</body>
</html>
